@@ -92,7 +92,7 @@ class RectvisionConverter():
 
         rearranged_annotations = {}
         total_data = len(annotation_prop)
-        data_split = random.choices(['train', 'test', 'val'], weights = [self.train_split, self.test_split, validation_split], k=total_data)
+        data_split = random.choices(['train', 'test', 'val'], weights = [self.train_split, self.test_split, self.validation_split], k=total_data)
         for data_tag, annon_prop in tqdm(zip(data_split, annotation_prop), desc = 'getting annotations'):
             image_name = annon_prop['file']['name']
             if image_name not in rearranged_annotations:
@@ -103,6 +103,9 @@ class RectvisionConverter():
                 rearranged_annotations[image_name]['points'] = []
             if 'labels' not in rearranged_annotations[image_name]:
                 rearranged_annotations[image_name]['labels'] = []
+            if 'data_tag' not in rearranged_annotations[image_name]:
+                rearranged_annotations[image_name]['data_tag'] = None
+
             rearranged_annotations[image_name]['image_id'] = annon_prop['file_id']
             rearranged_annotations[image_name]['image_url'] = annon_prop['file']['url']
             rearranged_annotations[image_name]['image_height'] =annon_prop['image_height']
@@ -110,7 +113,7 @@ class RectvisionConverter():
             rearranged_annotations[image_name]['image_channels'] = 3
             rearranged_annotations[image_name]['points'].append(annon_prop['points'])
             rearranged_annotations[image_name]['labels'].append(annon_prop['label']['value'])
-            rearranged_annotations[image_name]['data_tag'].append(data_tag)
+            rearranged_annotations[image_name]['data_tag'] = data_tag
         return rearranged_annotations
       
 
